==> haskell-descriptive-0.9.4-63-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-descriptive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: descriptive
version: 0.9.4
id: descriptive-0.9.4-DibpGSvEqbqAdSNOftyefh
key: descriptive-0.9.4-DibpGSvEqbqAdSNOftyefh
license: BSD3
copyright: 2015 Chris Done
maintainer: chrisdone@gmail.com
stability: Experimental
homepage: https://github.com/chrisdone/descriptive
synopsis: Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.
description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.
category: Parsing
author: Chris Done
exposed: True
indefinite: False
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.JSON Descriptive.Options
hidden-modules: Descriptive.Internal
abi: 0878b43decc476f8e74c9796dab08b6c
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/descriptive-0.9.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/descriptive-0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/descriptive-0.9.4
hs-libraries: HSdescriptive-0.9.4-DibpGSvEqbqAdSNOftyefh
depends:
    aeson-1.2.1.0-JssfvwcKPt8HWgsY2AQth base-4.10.0.0
    bifunctors-5.4.2-EkvLHEGusmL2QBUCGZ7PSE containers-0.5.10.2
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    scientific-0.3.5.1-imIXdjJRiA7LRtcu2MlFY
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz transformers-0.5.2.0
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
abi-depends: aeson-1.2.1.0-JssfvwcKPt8HWgsY2AQth=ba26dc5029b1e3a2d7e2a3e61dfdb816
             base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bifunctors-5.4.2-EkvLHEGusmL2QBUCGZ7PSE=339c00834bb4e63000d8fbc198c7bd3f
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=dff2eda61fc7cfa040a2eb3f0192c69a
             scientific-0.3.5.1-imIXdjJRiA7LRtcu2MlFY=9adb13ae6ad98888a5dcc657e850fcfc
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=23f6c0fe109d2ea8c2d28bae9257ae6c
haddock-interfaces: /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html: /usr/share/doc/haskell-descriptive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-descriptive-0.9.4-65-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-descriptive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: descriptive
version: 0.9.4
id: descriptive-0.9.4-DlEcXoJfIV68zvihfdi4F5
key: descriptive-0.9.4-DlEcXoJfIV68zvihfdi4F5
license: BSD3
copyright: 2015 Chris Done
maintainer: chrisdone@gmail.com
stability: Experimental
homepage: https://github.com/chrisdone/descriptive
synopsis: Self-describing consumers/parsers; forms, cmd-line args, JSON, etc.
description:
    Self-describing consumers/parsers. See the README.md for more information. It is currently EXPERIMENTAL.
category: Parsing
author: Chris Done
exposed: True
indefinite: False
exposed-modules:
    Descriptive Descriptive.Char Descriptive.Form Descriptive.Formlet
    Descriptive.JSON Descriptive.Options
hidden-modules: Descriptive.Internal
abi: 581845029f1a50da04ea9ef540eef85b
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/descriptive-0.9.4
library-dirs: /usr/lib/ghc-8.2.1/site-local/descriptive-0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.1/descriptive-0.9.4
hs-libraries: HSdescriptive-0.9.4-DlEcXoJfIV68zvihfdi4F5
depends:
    aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y base-4.10.0.0
    bifunctors-5.4.2-EkvLHEGusmL2QBUCGZ7PSE containers-0.5.10.2
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz transformers-0.5.2.0
    vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi
abi-depends: aeson-1.2.2.0-HUWi9FT4nd97NZtDZTzF1y=5e6b7bed78b23d60beb18bffc251a955
             base-4.10.0.0=835a16347ec1b210054efd02671c29ee
             bifunctors-5.4.2-EkvLHEGusmL2QBUCGZ7PSE=339c00834bb4e63000d8fbc198c7bd3f
             containers-0.5.10.2=dd4e66fa9ac268f47a15786f1100b042
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=dff2eda61fc7cfa040a2eb3f0192c69a
             scientific-0.3.5.2-KczHvPTRxl0EYfM8aLeb6Q=4e1885ea3bd9d96a68a990bad22946fe
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=9217a19661a41b462c62d1a4bdf2e9b1
             transformers-0.5.2.0=2645d250dd615ce454f807270041c5ea
             vector-0.12.0.1-CnPH69pDwM4A5esizlXfXi=23f6c0fe109d2ea8c2d28bae9257ae6c
haddock-interfaces: /usr/share/doc/haskell-descriptive/html/descriptive.haddock
haddock-html: /usr/share/doc/haskell-descriptive/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
